

.. autosummary::
    :toctree: _generated/physics

    zfit_physics.pdf.Argus
    zfit_physics.pdf.RelativisticBreitWigner
    zfit_physics.pdf.CMSShape
    zfit_physics.pdf.Cruijff
    zfit_physics.pdf.ErfExp
    zfit_physics.pdf.Novosibirsk
    zfit_physics.pdf.Tsallis
